OHAResultMap

Type Alias OHAResultMap 

pub type OHAResultMap = HashMap<DefId, Vec<(OwnedHeap, Vec<bool>)>>;
This is the type for storing the heap analysis results. The result is represented as a hashmap, where the key is DefId and the value contains the information of whether the type contains data on heap. Since a type could be a enumerate type, the value is represented as a vec, indicating the heap information of each variant. Also, because it may contain type parameters or generic types, the heap information is a tuple containing the information of each type parameter.

Aliased Type

pub struct OHAResultMap { /* private fields */ }